<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapXManual</name>
    <message>
        <location filename="../SnapXManualInit.js" line="+2"/>
        <source>&amp;X/Y from Points</source>
        <translation>&amp;X/Y z punktów</translation>
    </message>
</context>
</TS>
